@@ -1,3 +1,3 @@
 from .client import InstagramClient
-from .client_browser import InstagramClientBrowser
+from .client_browser import InstagramBrowserClient
 from .config import InstagramConfig
